2D Body Keypoint Datasets - PocketPose 0.0.1 documentation

Hide navigation sidebar
Hide table of contents sidebar

Get Started

- Installation
- Contributing to PocketPose
- FAQs

User Guides

- Inference
- Model Analysis
- How to Deploy

Advanced Guides

- Understanding the Dataflow
- Implement New Models
- Decoders
- Customize Datasets

Model Zoo

- Models
- 2D Body Keypoint Models
- 3D Body Keypoint Models
- 2D Face Keypoint Models
- 2D Hand Keypoint Models
- 2D Whole-Body Keypoint Models
- 2D Animal Keypoint Models

Dataset Zoo

- Datasets
- 2D Body Keypoint Datasets
- 2D Face Keypoint Datasets
- 2D Hand Keypoint Datasets

API Reference

- API Reference
  Toggle navigation of API Reference
  - `pocketpose`
    Toggle navigation of pocketpose
    - `pocketpose.benchmarks`
      Toggle navigation of pocketpose.benchmarks
      - `pocketpose.benchmarks.eval_coco`
      - `pocketpose.benchmarks.eval_coco_full`
      - `pocketpose.benchmarks.eval_coco_sp`
    - `pocketpose.converters`
      Toggle navigation of pocketpose.converters
      - `pocketpose.converters.base_converter`
      - `pocketpose.converters.onnx2tf`
      - `pocketpose.converters.tf2tflite`
      - `pocketpose.converters.torch2onnx`
      - `pocketpose.converters.torch2tflite`
    - `pocketpose.datasets`
      Toggle navigation of pocketpose.datasets
      - `pocketpose.datasets.factory`
      - `pocketpose.datasets.registry`
      - `pocketpose.datasets.skeletons`
    - `pocketpose.functional`
      Toggle navigation of pocketpose.functional
      - `pocketpose.functional.converters`
    - `pocketpose.graphics`
      Toggle navigation of pocketpose.graphics
      - `pocketpose.graphics.pose_visualizer`
    - `pocketpose.models`
      Toggle navigation of pocketpose.models
      - `pocketpose.models.body`
        Toggle navigation of pocketpose.models.body
        - `pocketpose.models.body.baseline`
        - `pocketpose.models.body.efficientpose`
        - `pocketpose.models.body.efficientpose_nas`
        - `pocketpose.models.body.litehrnet`
        - `pocketpose.models.body.movenet`
        - `pocketpose.models.body.posenet`
        - `pocketpose.models.body.rtmpose`
      - `pocketpose.models.decoder`
        Toggle navigation of pocketpose.models.decoder
        - `pocketpose.models.decoder.base_decoder`
        - `pocketpose.models.decoder.heatmap`
        - `pocketpose.models.decoder.posenet`
        - `pocketpose.models.decoder.simcc`
      - `pocketpose.models.interfaces`
        Toggle navigation of pocketpose.models.interfaces
        - `pocketpose.models.interfaces.imodel`
        - `pocketpose.models.interfaces.mmposemodel`
        - `pocketpose.models.interfaces.onnxmodel`
        - `pocketpose.models.interfaces.tflitemodel`
      - `pocketpose.models.wholebody`
        Toggle navigation of pocketpose.models.wholebody
        - `pocketpose.models.wholebody.blazepose`
      - `pocketpose.models.factory`
      - `pocketpose.models.registry`
    - `pocketpose.utils`
      Toggle navigation of pocketpose.utils
      - `pocketpose.utils.stats`
        Toggle navigation of pocketpose.utils.stats
        - `pocketpose.utils.stats.tflite`
      - `pocketpose.utils.io`
      - `pocketpose.utils.registry`
    - `pocketpose.apis`
    - `pocketpose.inferencer`
    - `pocketpose.summarize_mmpose_model`
    - `pocketpose.summarize_models`
    - `pocketpose.version`

Back to top
Edit this page
Toggle table of contents sidebar

# 2D Body Keypoint Datasets